fetch: cache collected

This avoids recollecting the cache files over and over again.

For example, `dvc fetch` noop in `dvc-bench` went from ~30sec down to ~10sec
for me.

Next step is to also cache remote index, so we don't have to waste those
~10sec checking files in the remote.

Related https://github.com/iterative/dvc-data/pull/376
This commit is contained in:
Ruslan Kuprieiev
2023-06-12 04:31:37 +03:00
parent 0597311439
commit 2ed677057d
4 changed files with 55 additions and 29 deletions
+1 -1
View File
@@ -34,7 +34,7 @@ dependencies = [
"configobj>=5.0.6",
"distro>=1.3",
"dpath<3,>=2.1.0",
"dvc-data>=1.5.0,<1.6.0",
"dvc-data>=1.6.1,<1.7.0",
"dvc-http>=2.29.0",
"dvc-render>=0.3.1,<1",
"dvc-studio-client>=0.9.2,<1",